@@ -199,11 +199,11 @@ void About_Dialog(GtkWindow *parent)
 }
 
 // FIXME!  Horrible hack to get around a symbol clash on Win32.
-#define SearchPathA SearchPath
+#define SearchPathHandlerA SearchPathHandler
 
 struct PathDialogData
 {
-	SearchPath sp;
+	SearchPathHandler sp;
 	ImageSelector *is;
 	PathEditor *pe;
 };
