@@ -11,10 +11,11 @@
 #include "stpui_widgets/units.h"
 #include "support/pageextent.h"
 #include "support/layoutrectangle.h"
+#include "support/thread.h"
 #include "effects/ppeffect.h"
 
 #include "layoutdb.h"
-
+#include "layout_imageinfo.h"
 class Layout_ImageInfo;
 class PhotoPrint_State;
 class Progress;
@@ -26,10 +27,15 @@ class Progress;
 #define PPLAYOUT_PROFILE 8
 #define PPLAYOUT_BACKGROUND 16
 #define PPLAYOUT_EFFECTS 32
+#define PPLAYOUT_DUPLICATE 64
+
 
 class Layout : public virtual PageExtent
 {
 	public:
+
+	// Housekeeping
+
 	Layout(PhotoPrint_State &state,Layout *oldlayout=NULL);
 	virtual ~Layout();
 	virtual const char *GetType()=0;
@@ -39,30 +45,46 @@ class Layout : public virtual PageExtent
 	virtual void TransferImages(Layout *oldlayout,Progress *p=NULL);
 	virtual void Clear();
 	virtual int GetPages();
+	virtual int FreeSlots();	// Count the number of free slots on the current page
+	virtual void Reflow();
+
 	virtual ImageSource *GetImageSource(int page,CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL,int res=0);
-	virtual IS_TYPE GetColourSpace(CMColourDevice target);
+	virtual IS_TYPE GetColourSpace(CMColourDevice target);	// Do we still need this?
 	virtual void UpdatePageSize()=0;
 	virtual void LayoutToDB(LayoutDB &db);
 	virtual void DBToLayout(LayoutDB &db);
-	virtual void Reflow();
-	virtual GtkWidget *CreateWidget();
-	virtual void RefreshWidget(GtkWidget *widget);
+
+	// Image list / selections
+
 	virtual Layout_ImageInfo *FirstImage();
 	virtual Layout_ImageInfo *NextImage();
-	virtual void SelectAll();
-	virtual void SelectNone();
 	virtual Layout_ImageInfo *FirstSelected();
 	virtual Layout_ImageInfo *NextSelected();
+	virtual int CountSelected();
+	virtual void SelectAll();
+	virtual void SelectNone();
 	virtual Layout_ImageInfo *ImageAtCoord(int x,int y);
 	virtual int GetCurrentPage();
 	virtual void SetCurrentPage(int page);
+
+
+	// UI-related
+
+	virtual GtkWidget *CreateWidget();
+	virtual void RefreshWidget(GtkWidget *widget);
 	virtual void Print(Progress *p);
-	virtual void (*SetUnitFunc())(GtkWidget *wid,enum Units unit);
 	virtual void DrawPreviewBG(GtkWidget *widget,int xpos,int ypos,int width,int height);
 	virtual void DrawPreview(GtkWidget *widget,int xpos,int ypos,int width,int height);
 	virtual void SetBackground(const char *filename);
 	virtual void FlushThumbnails();
+	virtual void FlushHRPreviews();
+	virtual void CancelRenderThreads();
+	virtual void (*SetUnitFunc())(GtkWidget *wid,enum Units unit);
+
+	PhotoPrint_State &state;
+
 	protected:
+
 	int xoffset,yoffset;
 	int pages;
 	int currentpage;
@@ -71,7 +93,6 @@ class Layout : public virtual PageExtent
 	GdkPixbuf *background;
 	GdkPixbuf *backgroundtransformed;
 	// Housekeeping
-	PhotoPrint_State &state;
 	GList *imagelist;
 	GList *iterator;
 	// For thumbnails and preview...
@@ -79,47 +100,7 @@ class Layout : public virtual PageExtent
 	GdkGC *gc;
 	GdkColor bgcol;
 	friend class Layout_ImageInfo;
-};
-
-
-class Layout_ImageInfo : public PPEffectHeader
-{
-	public:
-	Layout_ImageInfo(Layout &layout,const char *filename,int page,bool allowcropping=false,PP_ROTATION rotation=PP_ROTATION_AUTO);
-	Layout_ImageInfo(Layout &layout,Layout_ImageInfo *oldii,int page,bool allowcropping=false,PP_ROTATION rotation=PP_ROTATION_AUTO);
-	virtual ~Layout_ImageInfo();
-	virtual GdkPixbuf *GetThumbnail();
-	virtual GdkPixbuf *GetThumbnailNoEffects();
-	virtual ImageSource *GetImageSource(CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL);
-	virtual LayoutRectangle *GetBounds();
-	virtual ImageSource *ApplyMask(ImageSource *is);
-	virtual void DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int width,int height);
-	virtual void SetMask(const char *filename);
-	virtual const char *GetFilename();
-	virtual bool GetSelected();
-	virtual void SetSelected(bool sel);
-	virtual void ToggleSelected();
-	virtual void FlushThumbnail();
-	virtual void AssignProfile(const char *filename);
-	virtual const char *GetAssignedProfile();
-	virtual void SetRenderingIntent(LCMSWrapper_Intent intent);
-	virtual LCMSWrapper_Intent GetRenderingIntent();
-	int page;
-	bool allowcropping;
-	LayoutRectangle_Alignment crop_hpan;
-	LayoutRectangle_Alignment crop_vpan;
-	enum PP_ROTATION rotation;
-	protected:
-	Layout &layout;
-	char *filename;
-	char *maskfilename;
-	GdkPixbuf *thumbnail;
-	GdkPixbuf *mask;
-	GdkPixbuf *transformed;
-	bool selected;
-	char *customprofile;
-	LCMSWrapper_Intent customintent;
-	friend class Layout;
+	friend class hr_payload;
 };
 
 
