@@ -58,15 +58,24 @@ Layout_ImageInfo::Layout_ImageInfo(Layout &layout, const char *filename, int pag
 	else
 		this->filename=strdup(filename);
 
+	ImageSource *is=ISLoadImage(this->filename);
+	width=is->width;
+	height=is->height;
+	xres=is->xres;
+	yres=is->yres;
+	// FIXME - can we grab the embedded profile's name here (for the ImageInfo widget)?
+	delete is;
+
 	GetThumbnail();
 }
 
 
 Layout_ImageInfo::Layout_ImageInfo(Layout &layout, Layout_ImageInfo *ii, int page, bool allowcropping, PP_ROTATION rotation)
-	: PPEffectHeader(), page(page), allowcropping(allowcropping), crop_hpan(CENTRE), crop_vpan(CENTRE),
+	: PPEffectHeader(*ii), page(page), allowcropping(allowcropping), crop_hpan(CENTRE), crop_vpan(CENTRE),
 	rotation(rotation), layout(layout), maskfilename(NULL), thumbnail(NULL), mask(NULL), hrpreview(NULL),
 	selected(false), customprofile(NULL), customintent(LCMSWRAPPER_INTENT_DEFAULT), hrrenderthread(NULL)
 {
+	// Effects are copied by the "PPEffectHeader(*ii) above
 	if(ii)
 	{
 		// We duplicate and reference the thumbnail and mask from the old image...
@@ -77,14 +86,15 @@ Layout_ImageInfo::Layout_ImageInfo(Layout &layout, Layout_ImageInfo *ii, int pag
 		if(mask)
 			g_object_ref(G_OBJECT(mask));
 
+		// Duplicate name of manually-applied profile...
 		if(ii->customprofile)
 		{
 			customprofile=strdup(ii->customprofile);
 			cerr << "Copying profile: " << ii->customprofile << endl;
 		}
-		
 		customintent=ii->customintent;
 	
+		// Copy general data
 		if(ii->filename)
 			this->filename=strdup(ii->filename);
 		if(ii->maskfilename)
@@ -94,6 +104,10 @@ Layout_ImageInfo::Layout_ImageInfo(Layout &layout, Layout_ImageInfo *ii, int pag
 		crop_hpan=ii->crop_hpan;
 		crop_vpan=ii->crop_vpan;
 		rotation=ii->rotation;
+		width=ii->width;
+		height=ii->height;
+		xres=ii->xres;
+		yres=ii->yres;
 	}
 }
 
@@ -148,7 +162,11 @@ class hr_payload
 
 		for(int i=0;i<75;++i)
 		{
+#ifdef WIN32
+			Sleep(10);
+#else
 			usleep(10000);
+#endif
 			if(t->TestBreak())
 			{
 				cerr << "Got break signal while pausing - Releasing" << endl;
@@ -283,7 +301,8 @@ class hr_payload
 			LayoutRectangle r(gdk_pixbuf_get_width(p->transformed),gdk_pixbuf_get_height(p->transformed));
 			LayoutRectangle target(p->xpos,p->ypos,p->width,p->height);
 
-			RectFit *fit=r.Fit(target,p->ii->allowcropping,p->ii->rotation,p->ii->crop_hpan,p->ii->crop_vpan);
+			// Disallow rotation here since the image will be rotated already.
+			RectFit *fit=r.Fit(target,p->ii->allowcropping,PP_ROTATION_NONE,p->ii->crop_hpan,p->ii->crop_vpan);
 			int dw=fit->width;
 			int dh=fit->height;
 		
@@ -712,7 +731,22 @@ GdkPixbuf *Layout_ImageInfo::GetThumbnail()
 LayoutRectangle *Layout_ImageInfo::GetBounds()
 {
 	// Dummy function - override in subclasses!
-	LayoutRectangle *result=new LayoutRectangle(0,0,100,100);
+//	LayoutRectangle *result=new LayoutRectangle(0,0,100,100);
+//	return(result);
+	throw "Layout_ImageInfo::GetBounds() method should be overridden by subclass!";
+}
+
+
+RectFit *Layout_ImageInfo::GetFit(double scale)
+{
+	RectFit *result=NULL;
+	LayoutRectangle *bounds=GetBounds();
+	bounds->Scale(scale);
+
+	LayoutRectangle r(width,height);
+	result=r.Fit(*bounds,allowcropping,rotation,crop_hpan,crop_vpan);
+
+	delete bounds;
 	return(result);
 }
 
@@ -876,6 +910,30 @@ LCMSWrapper_Intent Layout_ImageInfo::GetRenderingIntent()
 }
 
 
+int Layout_ImageInfo::GetWidth()
+{
+	return(width);
+}
+
+
+int Layout_ImageInfo::GetHeight()
+{
+	return(height);
+}
+
+
+int Layout_ImageInfo::GetXRes()
+{
+	return(xres);
+}
+
+
+int Layout_ImageInfo::GetYRes()
+{
+	return(yres);
+}
+
+
 void Layout_ImageInfo::ObtainMutex()
 {
 	cerr << "In custom Obtain method - flushing preview..." << endl;
