@@ -71,12 +71,17 @@ Layout_NUp_ImageInfo::~Layout_NUp_ImageInfo()
 }
 
 
-void Layout_NUp_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int width,int height)
+LayoutRectangle *Layout_NUp_ImageInfo::GetBounds()
 {
 	Layout_NUp *l=(Layout_NUp *)&layout;
-	LayoutRectangle *target=l->GetLayoutRectangle(row,column);
+	return(l->GetLayoutRectangle(row,column));
+}
+
+void Layout_NUp_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int width,int height)
+{
+	LayoutRectangle *target=GetBounds();
 	double scale=width;
-	scale/=l->pagewidth;
+	scale/=layout.pagewidth;
 	target->Scale(scale);
 	Layout_ImageInfo::DrawThumbnail(widget,xpos+target->x,ypos+target->y,target->w,target->h);
 	delete target;
@@ -252,7 +257,7 @@ ImageSource *Layout_NUp::GetImageSource(int page,CMColourDevice target,CMTransfo
 				if(img)
 				{
 					LayoutRectangle r(img->width,img->height);
-					LayoutRectangle *target=GetLayoutRectangle(ii->row,ii->column);
+					LayoutRectangle *target=ii->GetBounds();
 					double scale=res;
 					scale/=72.0;
 					target->Scale(scale);
@@ -275,8 +280,16 @@ ImageSource *Layout_NUp::GetImageSource(int page,CMColourDevice target,CMTransfo
 					if(img->height<fit->height)
 						fit->height=img->height;
 
+					cerr << "xoffset: " << fit->xoffset << endl;
+					cerr << "yoffset: " << fit->yoffset << endl;
+
 					if(ii->allowcropping)
+					{
+						cerr << "Cropping" << endl;
 						img=new ImageSource_Crop(img,fit->xoffset,fit->yoffset,fit->width,fit->height);
+					}
+					else
+						cerr << "Not cropping" << endl;
 
 					img=ii->ApplyMask(img);
 
