@@ -49,10 +49,8 @@ class Layout_Single_ImageInfo : public Layout_ImageInfo
 	virtual ~Layout_Single_ImageInfo();
 	void DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int width,int height);
 	virtual ImageSource *GetImageSource(CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL);
-	int image_width;
-	int image_height;
-	double native_xres;
-	double native_yres;
+	virtual LayoutRectangle *GetBounds();	// The dimensions of the image's "slot".
+	virtual RectFit *GetFit(double scale);	// Details of the image's size after fitting to its slot.
 	float hscale;
 	float vscale;
 	private:
