@@ -28,8 +28,8 @@ class PhotoPrint_State : public ConfigFile, public ConfigDB
 	PrintOutput printoutput;
 	GPrinter printer;
 	ProfileManager profilemanager;
-	SearchPath bordersearchpath;
-	SearchPath backgroundsearchpath;
+	SearchPathHandler bordersearchpath;
+	SearchPathHandler backgroundsearchpath;
 	bool batchmode;
 	protected:
 	static ConfigTemplate Template[];
