@@ -160,7 +160,7 @@ static void page_changed(GtkWidget *wid,gpointer *ob)
 
 	pp_layout_poster_pageview_set_page(pv,pagesperposter*(gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lo->page))-1));
 
-	pp_imagecontrol_refresh(PP_IMAGECONTROL(lo->imagecontrol));
+	pp_imagecontrol_set_image(PP_IMAGECONTROL(lo->imagecontrol));
 	g_signal_emit(G_OBJECT (lo),pp_layout_poster_signals[CHANGED_SIGNAL], 0);
 }
 
@@ -232,6 +232,8 @@ void pp_layout_poster_refresh(pp_Layout_Poster *ob)
 	g_signal_handlers_unblock_matched (G_OBJECT(ob->voverlap),G_SIGNAL_MATCH_DATA,
 		0, 0, NULL, NULL, ob);
 
+	pp_imagecontrol_refresh(PP_IMAGECONTROL(ob->imagecontrol));
+
 	pp_Layout_Poster_PageView *pv=PP_LAYOUT_POSTER_PAGEVIEW(ob->pageview);
 	if(pv)
 		pp_layout_poster_pageview_refresh(pv);
