@@ -300,8 +300,12 @@ pp_layout_single_pageview_expose( GtkWidget      *widget,
 	pageview->scale=pageview->width;
 	pageview->scale/=pageview->layout->pagewidth;
 
+	cerr << "Pageview: Drawing preview" << endl;
+
 	pageview->layout->DrawPreview(widget,pageview->left,pageview->top,pageview->width,pageview->height);
 
+	cerr << "Pageview: done" << endl;
+
 	return FALSE;
 }
 
