@@ -2,7 +2,7 @@
  * lcmswrapper.cpp - encapsulates typical "user" functions of LittleCMS,
  * providing a Profile and Transform class
  *
- * Copyright (c) 2004 by Alastair M. Robinson
+ * Copyright (c) 2004-2008 by Alastair M. Robinson
  * Distributed under the terms of the GNU General Public License -
  * see the file named "COPYING" for more details.
  *
@@ -19,7 +19,7 @@
 
 #include <lcms.h>
 #include "md5.h"
-#include "../imagesource/imagesource_types.h"
+#include "imagesource_types.h"
 
 
 enum LCMSWrapper_Intent
@@ -42,13 +42,17 @@ class CMSProfile
 {
 	public:
 	CMSProfile(const char *filename);
-	CMSProfile(char *buffer,int length);
-	CMSProfile(CMSRGBPrimaries &primaries,CMSRGBGamma &gamma,CMSWhitePoint &whitepoint);
-	CMSProfile(CMSGamma &gamma,CMSWhitePoint &whitepoint);
+	CMSProfile(char *buffer,int length); // Should remain valid for lifetime of CMSProfile
+	CMSProfile(CMSRGBPrimaries &primaries,CMSRGBGamma &gamma,CMSWhitePoint &whitepoint); // Create virtual RGB profile
+	CMSProfile(CMSGamma &gamma,CMSWhitePoint &whitepoint); // Create virtual Grey profile
+	CMSProfile(CMSWhitePoint &whitepoint); // Create a virtual LAB profile
+	CMSProfile(); // Create a virtual sRGB profile
+	CMSProfile(const CMSProfile &src); // Copy constructor
 	~CMSProfile();
 	enum IS_TYPE GetColourSpace();
 	enum IS_TYPE GetDeviceLinkOutputSpace();
 	bool IsDeviceLink();
+	bool IsV4();
 	const char *GetName();
 	const char *GetManufacturer();
 	const char *GetModel();
@@ -57,13 +61,19 @@ class CMSProfile
 	const char *GetCopyright();
 	const char *GetFilename();
 	MD5Digest *GetMD5();
+	bool Save(const char *filename);
 	bool operator==(const CMSProfile &other);
 	protected:
+	void CalcMD5();
 	MD5Digest *md5;
 	cmsHPROFILE prof;
-	char *filename;
+	bool generated;	// Was this profile generated on the fly?
+	char *filename;	// Only used if profile is on disk.
+	char *buffer;	// Only used if profile
+	int buflen;		// is loaded from memory
 	friend class CMSTransform;
 	friend class CMSProofingTransform;
+	friend std::ostream& operator<<(std::ostream &s,CMSProfile &sp);
 };
 
 
@@ -161,6 +171,13 @@ class CMSRGBGamma
 		gammatables[1]=greengamma.GetGammaTable();
 		gammatables[2]=bluegamma.GetGammaTable();
 	}
+	CMSRGBGamma(float gamma)
+		: redgamma(gamma),greengamma(gamma),bluegamma(gamma)
+	{
+		gammatables[0]=redgamma.GetGammaTable();
+		gammatables[1]=greengamma.GetGammaTable();
+		gammatables[2]=bluegamma.GetGammaTable();
+	}
 	protected:
 	CMSGamma redgamma,greengamma,bluegamma;
 	LPGAMMATABLE gammatables[3];
