@@ -17,7 +17,7 @@
 #define _(x) gettext(x)
 
 #define SYSTEMMONITORPROFILE_ESCAPESTRING "<System monitor profile>"
-
+#define BUILTINSRGB_ESCAPESTRING "<Built-in sRGB profile>"
 using namespace std;
 
 
@@ -26,7 +26,7 @@ using namespace std;
 
 ConfigTemplate ProfileManager::Template[]=
 {
- 	ConfigTemplate("DefaultRGBProfile","sRGB_IEC61966-2-1_noBPC.icc"),
+ 	ConfigTemplate("DefaultRGBProfile","BUILTINSRGB_ESCAPESTRING>"),
 	ConfigTemplate("DefaultRGBProfileActive",int(1)),
 	ConfigTemplate("DefaultCMYKProfile","USWebCoatedSWOP.icc"),
 	ConfigTemplate("DefaultCMYKProfileActive",int(1)),
@@ -37,7 +37,7 @@ ConfigTemplate ProfileManager::Template[]=
 	ConfigTemplate("ExportProfile",""),
 	ConfigTemplate("ExportProfileActive",int(0)),
 	ConfigTemplate("MonitorProfile",SYSTEMMONITORPROFILE_ESCAPESTRING),
-	ConfigTemplate("MonitorProfileActive",int(0)),
+	ConfigTemplate("MonitorProfileActive",int(1)),
 	ConfigTemplate("RenderingIntent",int(LCMSWRAPPER_INTENT_PERCEPTUAL)),
 	ConfigTemplate("ProofMode",int(CM_PROOFMODE_NONE)),
 #ifdef WIN32
@@ -50,13 +50,13 @@ ConfigTemplate ProfileManager::Template[]=
 
 
 ProfileManager::ProfileManager(ConfigFile *inifile,const char *section) :
-	ConfigDB(Template), SearchPath(), first(NULL), proffromdisplay_size(0)
+	ConfigDB(Template), SearchPathHandler(), first(NULL), proffromdisplay_size(0)
 {
 #ifndef WIN32
 	xdisplay = XOpenDisplay(NULL);
  	proffromdisplay=NULL;
 #endif
-	new SearchPathDBHandler(inifile,section,this,this,"ProfilePath");
+	new SearchPathHandlerDBHandler(inifile,section,this,this,"ProfilePath");
 	AddPath(FindString("ProfilePath"));
 	GetProfileFromDisplay();
 	if(proffromdisplay_size)
@@ -83,29 +83,41 @@ CMSProfile *ProfileManager::GetProfile(const char *name)
 	CMSProfile *result=NULL;
 	if(name && strlen(name))
 	{
-		char *fn=Search(name);
-
 		if(strcmp(name,SYSTEMMONITORPROFILE_ESCAPESTRING)==0 && proffromdisplay_size)
+		{
 #ifdef WIN32	
 			result=new CMSProfile(displayprofilename);
 #else
 			result=new CMSProfile((char *)proffromdisplay,proffromdisplay_size);
 #endif
-
-		if(fn && strlen(fn))
-		{
-			try
+			if(!result)
 			{
-				result=new CMSProfile(fn);
-			}
-			catch(const char *err)
-			{
-				free(fn);
-				throw err;
+				cerr << "Couldn't open monitor profile - falling back to builtin sRGB" << endl;
+				result=new CMSProfile();
 			}
 		}
-		if(fn)
-			free(fn);
+		else if(strcmp(name,BUILTINSRGB_ESCAPESTRING)==0)
+		{
+			result=new CMSProfile();
+		}
+		else
+		{
+			char *fn=Search(name);
+			if(fn && strlen(fn))
+			{
+				try
+				{
+					result=new CMSProfile(fn);
+				}
+				catch(const char *err)
+				{
+					free(fn);
+					throw err;
+				}
+			}
+			if(fn)
+				free(fn);
+		}
 	}
 	return(result);
 }
@@ -389,7 +401,10 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 
 		// Don't bother transforming if src/dest are the same profile...
 		if(*d1==*d2)
+		{
+			cerr << "Source and target profiles are identical - no need to transform" << endl;
 			return(NULL);
+		}
 
 		transform=Search(d1,d2,intent);
 		if(!transform)
@@ -532,7 +547,7 @@ static const char *findextension(const char *filename)
 const char *ProfileManager::GetNextFilename(const char *prev)
 {
 	const char *result=prev;
-	while((result=SearchPath::GetNextFilename(result)))
+	while((result=SearchPathHandler::GetNextFilename(result)))
 	{
 		const char *ext=findextension(result);
 		if(strncasecmp(ext,".ICM",4)==0)
@@ -551,21 +566,21 @@ const char *ProfileManager::GetNextFilename(const char *prev)
 void ProfileManager::AddPath(const char *path)
 {
 	FlushProfileInfoList();
-	SearchPath::AddPath(path);
+	SearchPathHandler::AddPath(path);
 }
 
 
 void ProfileManager::RemovePath(const char *path)
 {
 	FlushProfileInfoList();
-	SearchPath::RemovePath(path);
+	SearchPathHandler::RemovePath(path);
 }
 
 
 void ProfileManager::ClearPaths()
 {
 	FlushProfileInfoList();
-	SearchPath::ClearPaths();
+	SearchPathHandler::ClearPaths();
 }
 
 
@@ -582,6 +597,7 @@ void ProfileManager::BuildProfileInfoList()
 //	cerr << "Building ProfileInfo List:" << endl;
 	const char *f=NULL;
 	FlushProfileInfoList();
+	new ProfileInfo(*this,BUILTINSRGB_ESCAPESTRING);
 	while((f=GetNextFilename(f)))
 	{
 		if(!(FindProfileInfo(f)))
@@ -680,7 +696,6 @@ void ProfileInfo::GetInfo()
 {
 	if(iscached)
 		return;
-//	cerr << "Getting profile info for " << filename << endl;
 
 	CMSProfile *profile=profilemanager.GetProfile(filename);
 	if(profile)
