@@ -33,7 +33,7 @@ enum CMProofMode
 class CMTransformFactory;
 class ProfileInfo;
 
-class ProfileManager : public ConfigDB, public SearchPath
+class ProfileManager : public ConfigDB, public SearchPathHandler
 {
 	public:
 	ProfileManager(ConfigFile *Configfile,const char *section);
@@ -45,7 +45,7 @@ class ProfileManager : public ConfigDB, public SearchPath
 	void SetDefaultProfile(IS_TYPE colourspace,const char *name);
 	CMTransformFactory *GetTransformFactory();
 
-	// path handling - we override these functions from the SearchPath
+	// path handling - we override these functions from the SearchPathHandler
 	// so we can invalidate the ProfileInfo list when the path changes.
 	virtual void AddPath(const char *path);
 	virtual void RemovePath(const char *path);
