@@ -23,11 +23,19 @@
 #include <gtk/gtkfilechooser.h>
 #include <gtk/gtkmenuitem.h>
 
-#include "../support/generaldialogs.h"
+#include "generaldialogs.h"
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "gettext.h"
+#define _(x) gettext(x)
+#define N_(x) gettext_noop(x)
 
 #include "profileselector.h"
 
-static char *PS_ESCAPESTRING="Other...";
+static const char *PS_ESCAPESTRING=N_("Other...");
 
 using namespace std;
 
@@ -41,9 +49,46 @@ static guint profileselector_signals[LAST_SIGNAL] = { 0 };
 static void profileselector_class_init (ProfileSelectorClass *klass);
 static void profileselector_init (ProfileSelector *sel);
 
+class profsel_entry
+{
+	public:
+	profsel_entry(const char *filename,const char *uiname) : filename(NULL), uiname(NULL)
+	{
+		this->filename=g_strdup(filename);
+		this->uiname=g_strdup(uiname);
+	}
+	~profsel_entry()
+	{
+		if(filename)
+			g_free(filename);
+		if(uiname)
+			g_free(uiname);
+	}
+	int filenamecmp(profsel_entry &a)
+	{
+		return(strcmp(a.filename,filename));
+	}
+	int uinamecmp(profsel_entry &a)
+	{
+		return(strcmp(a.uiname,uiname));
+	}
+	gchar *filename;
+	gchar *uiname;
+};
+
+
 static int mycmp(const void *s1,const void *s2)
 {
-	return(strcmp((const char *)s1,(const char *)s2));
+	profsel_entry *ps1=(profsel_entry *)s1;
+	profsel_entry *ps2=(profsel_entry *)s2;
+	return(ps1->filenamecmp(*ps2));
+}
+
+static int mycmp_desc(const void *s1,const void *s2)
+{
+	profsel_entry *ps1=(profsel_entry *)s1;
+	profsel_entry *ps2=(profsel_entry *)s2;
+	return(ps1->uinamecmp(*ps2));
 }
 
 
@@ -84,7 +129,8 @@ static void rebuild_menu(ProfileSelector *c)
 	GList *iter=c->optionlist;
 	while(iter)
 	{
-		gchar *text=(gchar *)iter->data;
+		profsel_entry *ps=(profsel_entry *)iter->data;
+		gchar *text=ps->uiname;
 		GtkWidget *menu_item = gtk_menu_item_new_with_label (text);
 		gtk_menu_shell_append (GTK_MENU_SHELL (c->menu), menu_item);
 		gtk_widget_show (menu_item);
@@ -96,7 +142,6 @@ static void rebuild_menu(ProfileSelector *c)
 
 static void profileselector_build_options(ProfileSelector *c)
 {
-	cerr << "Building option list" << endl;
 	if(c->optionlist)
 	{
 		GList *element;
@@ -114,22 +159,25 @@ static void profileselector_build_options(ProfileSelector *c)
 	while(pi)
 	{
 		const char *filename=pi->GetFilename();
-		if(g_list_find_custom(c->optionlist,filename,mycmp))
-			cerr << "Profile already in list - ignoring" << endl;
-		else
+		const char *uiname=pi->GetDescription();
+		profsel_entry *ps=new profsel_entry(filename,uiname);
+		if(!g_list_find_custom(c->optionlist,ps,mycmp))
 		{
 			if(verifyprofile(c,pi))
 			{
-				c->optionlist=g_list_append(c->optionlist,g_strdup(filename));
+				profsel_entry *ps2=new profsel_entry(filename,uiname);
+				c->optionlist=g_list_append(c->optionlist,ps2);
 			}
 		}
+		delete ps;
 		pi=pi->Next();
 	}
 
-	c->optionlist=g_list_sort(c->optionlist,mycmp);
+	c->optionlist=g_list_sort(c->optionlist,mycmp_desc);
 
 	// "Other..." option, pops up a file selector.
-	c->optionlist=g_list_append(c->optionlist,g_strdup(PS_ESCAPESTRING));
+	profsel_entry *otherps=new profsel_entry(PS_ESCAPESTRING,gettext(PS_ESCAPESTRING));
+	c->optionlist=g_list_append(c->optionlist,otherps);
 
 	rebuild_menu(c);
 }
@@ -141,9 +189,14 @@ static void	profileselector_changed(GtkWidget *widget,gpointer user_data)
 	GtkOptionMenu *om=GTK_OPTION_MENU(c->optionmenu);
 
 	gint index=gtk_option_menu_get_history(om);
+
+	profsel_entry *ps=NULL;
 	const char *val=NULL;
 	if(c->optionlist)
-		val=(const char *)g_list_nth_data(c->optionlist,index);
+		ps=(profsel_entry *)g_list_nth_data(c->optionlist,index);
+
+	if(ps)
+		val=ps->filename;
 
 	if(val && strlen(val))
 	{
@@ -158,6 +211,13 @@ static void	profileselector_changed(GtkWidget *widget,gpointer user_data)
 			else
 				val=c->filename;
 		}
+		else if(index==c->currentidx)
+		{
+			// If the user has simply reselected the current profile
+			// we don't want to trigger a signal.
+			return;
+		}
+
 		if(val)
 			profileselector_set_filename(c,val);
 
@@ -179,30 +239,25 @@ profileselector_new (ProfileManager *pm,IS_TYPE colourspace,bool allowdevicelink
 	c->optionmenu=gtk_option_menu_new();
 	c->menu=NULL;  // Built on demand...
 
+	c->tips=gtk_tooltips_new();
+	gtk_tooltips_enable(c->tips);
+
 	gtk_box_pack_start(GTK_BOX(c),GTK_WIDGET(c->optionmenu),TRUE,TRUE,0);
 
-	GtkWidget *frame=gtk_frame_new(NULL);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame),GTK_SHADOW_IN);
-	gtk_box_pack_start(GTK_BOX(c),GTK_WIDGET(frame),TRUE,FALSE,0);
-
-	c->description=gtk_label_new("");
-	gtk_container_add(GTK_CONTAINER(frame),GTK_WIDGET(c->description));
-	
-	gtk_widget_show(c->description);
-	gtk_widget_show(frame);
 	gtk_widget_show(c->optionmenu);
 
 	profileselector_build_options(c);
 	g_signal_connect(c->optionmenu,"changed",G_CALLBACK(profileselector_changed),c);
 
 	gint index=gtk_option_menu_get_history(GTK_OPTION_MENU(c->optionmenu));
+	profsel_entry *pe=NULL;
 	const char *val=NULL;
 	if(c->optionlist)
-		val=(const char *)g_list_nth_data(c->optionlist,index);
+		pe=(profsel_entry *)g_list_nth_data(c->optionlist,index);
+	if(pe)
+		val=pe->filename;
 	if(val)
 		profileselector_set_filename(c,val);
-
-//	profileselector_changed(c->optionmenu,c);
 	
 	return(GTK_WIDGET(c));
 }
@@ -291,19 +346,25 @@ void profileselector_set_type(ProfileSelector *c,IS_TYPE colourspace)
 void profileselector_set_filename(ProfileSelector *c,const char *filename)
 {
 	char *fn=c->pm->MakeRelative(filename);
-//	if(verifyprofile(c,fn))
-//	{
+
+	try
+	{
 		if(c->filename)
 			free(c->filename);
 		c->filename=fn; // Don't free fn, c->filename has "adopted" it.
 		
 		// If the filename is not present, add it.
 
+		CMSProfile *tp=c->pm->GetProfile(c->filename);
+		profsel_entry tempps(c->filename,tp ? tp->GetDescription() : _("Please choose a valid ICC profile"));
+		delete tp;
+
 		GList *node;
-		if((node=g_list_find_custom(c->optionlist,c->filename,mycmp)))
+		if((node=g_list_find_custom(c->optionlist,&tempps,mycmp)))
 		{
 			gint i=g_list_position(c->optionlist,node);
-			gtk_option_menu_set_history(GTK_OPTION_MENU(c->optionmenu),i);			
+			gtk_option_menu_set_history(GTK_OPTION_MENU(c->optionmenu),i);		
+			c->currentidx=i;
 		}
 		else
 		{
@@ -311,33 +372,26 @@ void profileselector_set_filename(ProfileSelector *c,const char *filename)
 		                                         G_SIGNAL_MATCH_DATA,
 		                                         0, 0, NULL, NULL, c);
 
-			c->optionlist=g_list_append(c->optionlist,g_strdup(c->filename));
+			profsel_entry *newps=new profsel_entry(c->filename,tempps.uiname);
+			c->optionlist=g_list_append(c->optionlist,newps);
 			rebuild_menu(c);
-			gtk_option_menu_set_history(GTK_OPTION_MENU(c->optionmenu),g_list_length(c->optionlist)-1);
+			gint i=g_list_length(c->optionlist)-1;
+			gtk_option_menu_set_history(GTK_OPTION_MENU(c->optionmenu),i);
+			c->currentidx=i;
 
 			g_signal_handlers_unblock_matched (G_OBJECT (c->optionmenu), 
 		                                         G_SIGNAL_MATCH_DATA,
 		                                         0, 0, NULL, NULL, c);
 		}
 
-		try
-		{
-			CMSProfile *profile=c->pm->GetProfile(c->filename);
-			if(profile)
-			{
-				gsize in,out;
-				gchar *entry=g_locale_to_utf8(profile->GetDescription(),-1,&in,&out,NULL);
-				gtk_label_set_text(GTK_LABEL(c->description),entry);
-				delete profile;
-			}
-			else
-				gtk_label_set_text(GTK_LABEL(c->description),"Warning: can't open profile!");
-		}
-		catch(const char *err)
-		{
-			cerr << "Profile Selector: " << err << endl;
-		}
-//	}
+		gsize in,out;
+		gchar *entry=g_locale_to_utf8(c->filename,-1,&in,&out,NULL);
+		gtk_tooltips_set_tip(c->tips,c->optionmenu,entry,entry);
+	}
+	catch(const char *err)
+	{
+		cerr << "Profile Selector: " << err << endl;
+	}
 }
 
 
@@ -345,3 +399,4 @@ const char *profileselector_get_filename(ProfileSelector *p)
 {
 	return(p->filename);
 }
+
