@@ -1,7 +1,7 @@
 #include <iostream>
 
 #include "profilemanager.h"
-#include "../support/configdb.h"
+#include "configdb.h"
 
 using namespace std;
 
