@@ -34,13 +34,12 @@ class Progress
 		max=maxi;
 		return(true);
 	}
-	virtual void SetMessage(const char *msg)=0;
-	private:
+	virtual void SetMessage(const char *msg)
+	{
+	}
+	protected:
 	int current;
 	int max;
-	int counter;
-	int counter2;
-	int limit;
 };
 
 #endif
