@@ -20,7 +20,7 @@ using namespace std;
 class ProgressText : public Progress
 {
 	public:
-	ProgressText() : counter(0), counter2(0), message(NULL)
+	ProgressText() : Progress(),counter(0), counter2(0), message(NULL)
 	{
 	}
 	virtual ~ProgressText()
@@ -31,15 +31,18 @@ class ProgressText : public Progress
 	virtual bool DoProgress(int i, int maxi)
 	{
 		Progress::DoProgress(i,maxi);
-		char *baton="/-\\|";
+		const char *baton="/-\\|";
 		if((counter==0) || (i==maxi))
 		{
 			if(i>maxi)
 				i=maxi;
-			if(message)
-				cerr << message << " ";
-			cerr << baton[counter2] << " " << ((i+1)*100)/maxi << "%\r";
-			if(i==maxi)
+//			if(message)
+//				cerr << message << " ";
+			if(maxi)
+				cerr << baton[counter2] << " " << ((i+1)*100)/maxi << "%\r";
+			else
+				cerr << baton[counter2] << " " << "\r";
+			if(i==maxi && maxi>0)
 				cerr << endl;
 			cerr.flush();
 			++counter2;
@@ -58,9 +61,12 @@ class ProgressText : public Progress
 			free(message);
 		message=NULL;
 		if(msg)
+		{
 			message=strdup(msg);
+			cerr << msg << endl;
+		}
 	}
-	private:
+	protected:
 	int counter;
 	int counter2;
 	int limit;
