@@ -21,7 +21,7 @@ class PTMutex
 	friend class Thread;
 };
 
-#elif defined HAVE_LIBPTHREAD
+#elif defined HAVE_LIBPTHREAD || defined HAVE_LIBPTHREADGC2
 
 #include <pthread.h>
 
