@@ -6,7 +6,7 @@
 #include <ostream>
 
 /*
-	SearchPath - a class to handle multiple search paths.
+	SearchPathHandler - a class to handle multiple search paths.
 	Written by Alastair M. Robinson to handle PhotoPrint's ICC profiles.
 
 	The following public functions are provided:
@@ -50,6 +50,8 @@
 	TODO: Make path separation character runtime definable for Win32 support.
 	2007-07-29: Added a conditional define to handle that at built time...
 
+	2008-07-15: Renamed class to SearchPathHandler to avoid Win32 name clash
+
 */
 
 
@@ -58,8 +60,6 @@
 #define SEARCHPATH_DELIMITER_S ";"
 #define SEARCHPATH_SEPARATOR '\\'
 #define SEARCHPATH_SEPARATOR_S "\\"
-// FIXME - nasty hack to get around a WIN32 namespace collision
-#undef SearchPath
 #else
 #define SEARCHPATH_DELIMITER_C ':'
 #define SEARCHPATH_DELIMITER_S ":"
@@ -70,11 +70,11 @@
 
 class SearchPathInstance;
 
-class SearchPath
+class SearchPathHandler
 {
 	public:
-	SearchPath();
-	virtual ~SearchPath();
+	SearchPathHandler();
+	virtual ~SearchPathHandler();
 	char *Search(const char *file);
 	char *MakeRelative(const char *file);
 	virtual void AddPath(const char *path);
@@ -91,7 +91,7 @@ class SearchPath
 	char *searchfilename;
 	SearchPathInstance *searchiterator;
 	friend class SearchPathInstance;
-	friend std::ostream& operator<<(std::ostream &s,SearchPath &sp);
+	friend std::ostream& operator<<(std::ostream &s,SearchPathHandler &sp);
 };
 
 #endif
