@@ -3,14 +3,14 @@
 
 #include "configdb.h"
 
-class SearchPathDBHandler : public ConfigDBHandler
+class SearchPathHandlerDBHandler : public ConfigDBHandler
 {
 	public:
-	SearchPathDBHandler(ConfigFile *file,const char *section,ConfigDB *db,SearchPath *sp,const char *pathparam)
+	SearchPathHandlerDBHandler(ConfigFile *file,const char *section,ConfigDB *db,SearchPathHandler *sp,const char *pathparam)
 		: ConfigDBHandler(file,section,db), db(db), sp(sp), pathparameter(pathparam)
 	{
 	}
-	virtual ~SearchPathDBHandler()
+	virtual ~SearchPathHandlerDBHandler()
 	{
 	}
 	virtual void LeaveSection()
@@ -28,7 +28,7 @@ class SearchPathDBHandler : public ConfigDBHandler
 	}
 	protected:
 	ConfigDB *db;
-	SearchPath *sp;
+	SearchPathHandler *sp;
 	const char *pathparameter;
 };
 
