@@ -39,7 +39,7 @@ struct Thread
 	int error;
 };
 
-#elif defined HAVE_LIBPTHREAD
+#elif defined HAVE_LIBPTHREAD || defined HAVE_LIBPTHREADGC2
 
 struct Thread
 {
